## DENK UTILS

Custom CV functions.


## Getting Started
```
pip install denku
```


## Contacts
<p>Issues should be raised directly in the repository. For professional support and recommendations please <a>welcomedenk@gmail.com</a>.</p>